<?php
class User_m extends MY_Model
{
	
	protected $_table_name = USERS_TABLE;
	public $_order_by = 'user_name';
	public $meta_filters = array();
	
	public $rules = array(
		'user_email' => array(
			'field' => 'user_email', 
			'label' => "User Email", 
			'rules' => 'trim|required|xss_clean'
		), 
		'user_password' => array(
			'field' => 'user_password', 
			'label' => 'Password', 
			'rules' => 'trim|required'
		)
	);
	
	public $login_rules = array(
		'login_name' => array(
			'field' => 'login_name', 
			'label' => "Login name", 
			'rules' => 'trim|required|xss_clean'
		), 
		'login_pass' => array(
			'field' => 'user_password', 
			'label' => 'Password', 
			'rules' => 'trim'
		)
	);
	
	public $register_rules = array(
		'user_name' => array(
			'field' => 'user_name', 
			'label' => 'Login name', 
			'rules' => 'trim|required|xss_clean'
		), 
		'user_nickname' => array(
			'field' => 'user_nickname', 
			'label' => 'Patient name', 
			'rules' => 'trim|required|xss_clean'
		), 
		'user_email' => array(
			'field' => 'user_email', 
			'label' =>'Patient email', 
			'rules' => 'trim|valid_email|required|xss_clean'
		), 
		'gender' => array(
			'field' => 'gender', 
			'label' => 'Gender', 
			'rules' => 'trim|required|xss_clean'
		),
		'birth_year' => array(
			'field' => 'birth_year', 
			'label' => 'Birth year', 
			'rules' => 'trim|required|xss_clean'
		),
		'user_phone' => array(
			'field' => 'user_phone', 
			'label' => 'Patient phone', 
			'rules' => 'trim|required|xss_clean'
		)
	);
	public $rules_admin = array(
		'user_name' => array(
			'field' => 'user_name', 
			'label' => 'Username', 
			'rules' => 'trim|required|xss_clean'
		), 
		'user_email' => array(
			'field' => 'user_email', 
			'label' =>'User Email', 
			'rules' => 'trim|valid_email|required|xss_clean'
		), 
		'user_nickname' => array(
			'field' => 'user_nickname', 
			'label' => 'Nickname', 
			'rules' => 'trim|required|xss_clean'
		),
		'user_password' => array(
			'field' => 'user_password', 
			'label' => 'Password', 
			'rules' => 'trim|matches[password_confirm]'
		),
		'password_confirm' => array(
			'field' => 'password_confirm', 
			'label' => 'Confirm password', 
			'rules' => 'trim|matches[user_password]'
		),
	);

	function __construct (){
		parent::__construct();		
	}
	
	function save($data, $id = NULL,$allow=false){
		$sess = $this->session->userdata('id');
		if(!empty($sess))$data[$this->get_field_prefixed('author_id')] = $sess;
		else $data[$this->get_field_prefixed('author_id')] = 0;
		return parent::save($data,$id,$allow);
	}
	
	private function allowed_controllers(){
		$user_types = config_item("user_types");
		$user_types[] = "user";
		foreach($user_types as $type)
			if($this->router->fetch_class() == $type)
				return false;
		return true;		
	}
	
	public function apply_filter($once = false){		
		if($this->allowed_controllers() ||$this->router->fetch_method() !='index'|| !$once)return;
		if(!empty($_GET) && empty($_GET["search"])){			
			foreach($_GET as $key=>$value){
				if(empty($value))
					continue;
				if(!in_array($key,$this->ignored_keys)){
					switch($key){
						case "s":
						$meta_conditions = "";
						if(!empty($this->meta_filters)){
								foreach($this->meta_filters as $f){
									$meta_conditions = " OR ID IN (SELECT item_id FROM ".$this->db->dbprefix(META_TABLE)." WHERE meta_key = '".$f."' AND meta_value LIKE '%".$value."%' AND meta_type = 'user') ";
								}
							}
							$this->db->where(" ( user_name LIKE '%".$value."%' OR user_email LIKE '%".$value."%' OR user_nickname LIKE '%".$value."%' ".$meta_conditions." ) ");
							
						break;
						case "is_manager"://yes-no
							if($value == "yes"){
								$this->db->where('user_privilages', 'administrator_eb4d8'); 
							}elseif($value == "no"){
								$this->db->where('user_privilages', 'customer_service'); 
							}else{
								$this->db->where('user_privilages != ', 'customer_service');
								$this->db->where('user_privilages != ', 'administrator_eb4d8');  
							}
						break;
					}
				}
			}
		}
	}
	public function login ($_from_lock=FALSE,$return_user=FALSE)	{		
		$userdata = array(
			'user_email' => $this->input->post('user_email'),
			'user_password' => $this->hashv($this->input->post('user_password')),
		);		
		$user = $this->get_by($userdata, TRUE);
		if(empty($user)){ 
			
			$user = $this->get_by(array(
				'user_name' => $this->input->post('user_email'),
				'user_password' => $this->hashv($this->input->post('user_password')),
			), TRUE);
		}
		// dump_exit($userdata);
		if (!empty($user)) {
			if($return_user)return $user;
			if($_from_lock){
				//login from lock
				$data = array(					
					'loggedin' => TRUE,
				);
				$this->session->set_userdata($data);
			}else{
				// Log in user
				$data = array(
					'name' => $user->user_name,
					'email' => $user->user_email,
					'lang' => $user->user_lang,
					'id' => $user->ID,
					'nickname' => $user->user_nickname,
					'loggedin' => TRUE,
				);
				$this->session->set_userdata($data);
			}
			return TRUE;
		}
		 
		return FALSE;
	}

	public function logout ()
	{
		$userdata = array(
			'name' => "",
			'email' => "",
			'lang' => "",
			'id' => "",
			'nickname' => "",
			'loggedin' => "",
		);
		$this->session->unset_userdata($userdata);
		$this->session->sess_destroy();
	}

	public function loggedin ()
	{
		return (bool) $this->session->userdata('loggedin');
	}
	
	public function get_new(){
		$user = new stdClass();
		$user->user_name = '';
		$user->user_email = '';
		$user->user_nickname = '';
		$user->user_password = '';
		$user->user_privilages = '';
		$user->user_lang = '';
		return $user;
	}

	public function hashv($string)
	{
		$enc = md5(md5($string)) . config_item('encryption_key');
		return hash('sha512', $enc);
	}
	
	public function get_avatar($id){
		$this->db->select('meta_value');
		$this->db->where('meta_type', 'user');
		$this->db->where('meta_key', 'avatar');
		$this->db->where('item_id', $id);
		$avatar = $this->db->get(META_TABLE);
		$avatar = $avatar->row();
		if(!empty($avatar))return $avatar->meta_value;else return '';
	}
	public function set_order_by($orderby){
		$this->_order_by = $orderby;
	}
	
	public function remove($id){
		$this->db->where('meta_type', 'user');
		$this->db->where('item_id', $id);
		$this->db->delete(META_TABLE);
		$filter = $this->_primary_filter;
		$id = $filter($id);
		if (!$id) {
			return FALSE;
		}
		$this->db->where($this->_primary_key, $id);
		$this->db->limit(1);
		return  $this->db->delete($this->_table_name);
	}
	
	public function hash_remember($data){
		$data = sha1(md5(md5($data)));
		return $data;
	}
	
}