<?php
class Media extends Admin_Controller
{

	public function __construct ()
	{
		parent::__construct();
		$this->load->model('media_m');
		$this->data["Module_title"] = _lang("Media");
	}

	public function index ()
	{
		if(!$this->_has_access)return;
		// Fetch all media_files
		$this->media_m->set_order_by("created_at DESC");
		$this->data['media_files'] = $this->media_m->get();
		$this->data['years'] = $this->media_m->available_years();	
		// Load view
		$this->sub_view('media/index');
		$this->load_admin_view();
	}

	public function add(){
		if(!$this->_has_access)return;
		$this->data['media'] = $this->media_m->get_new();
		$rules = $this->media_m->rules;
		$this->form_validation->set_rules($rules);
		if ($this->form_validation->run() == TRUE) {
			$data = $this->media_m->array_from_post(array(
				'media_title', 
				'media_slug', 
				'media_url', 
				'media_alt'
			));
			$result = $this->media_m->save($data);
			if($result){
					$msg = _lang('Media file added successfully');
			}else{ 
				$this->session->set_flashdata('result_type', 'danger');
				$msg = _lang('Error while adding Media file');
			}
			$this->session->set_flashdata('result', $msg);
			redirect($this->_backstage_dir.'/media');
		}
		$this->sub_view('media/add-2');
		$this->load_admin_view();
	}

	public function edit ($id = NULL)
	{
		if(!$this->_has_access)return;
		// Fetch a media or set a new one
		if ($id) {
			$this->data['media'] = $this->media_m->get($id);
			if(!$this->valid_object($this->data['media']))return;
			count($this->data['media']) || $this->data['errors'][] = _lang('Media file could not be found');
		}
		else {
			$this->data['media'] = $this->media_m->get_new();
		}
		// Set up the form
		$rules = $this->media_m->rules;
		$this->form_validation->set_rules($rules);
		
		// Process the form
		if ($this->form_validation->run() == TRUE) {
			$data = $this->media_m->array_from_post(array(
				'media_title', 
				'media_slug', 
				'media_url', 
				'media_alt'
			));
			$result = $this->media_m->save($data, $id);
			if($result){
				if(!empty($id))
					$msg = _lang('Media file updated successfully');				
			}else{ 
				$this->session->set_flashdata('result_type', 'danger');
				if(!empty($id))
					$msg = _lang('Error while updating Media file');
			}
			$this->session->set_flashdata('result', $msg);
			redirect($this->_backstage_dir.'/media');
		}
		
		// Load the view
		$this->sub_view('media/edit');
		$this->load_admin_view();
	}

	public function delete ($id)
	{
		if(!$this->_has_access)return;
		$media = $this->media_m->get($id);
		unlink(FCPATH.'media/'.$media->media_url);
		$result = $this->media_m->delete($id);
		if($result){
			if(!empty($id))
				$msg = _lang('Media file deleted successfully');				
		}else{ 
			$this->session->set_flashdata('result_type', 'danger');
			if(!empty($id))
				$msg = _lang('Error while deleting Media file');
		}
		$this->session->set_flashdata('result', $msg);
		redirect($this->_backstage_dir.'/media');
	}

	public function _unique_slug ($str)
	{
		// Do NOT validate if slug already exists
		// UNLESS it's the slug for the current media
		

		$id = $this->uri->segment(4);
		$this->db->where('media_slug', $this->input->post('media_slug'));
		! $id || $this->db->where('id !=', $id);
		$media = $this->media_m->get();
		
		if (count($media)) {
			$this->form_validation->set_message('_unique_slug', '%s should be unique');
			return FALSE;
		}
		
		return TRUE;
	}
	
}